==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/resource/ResourceQueryCondition2.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.resource;

import java.util.Date;
import java.util.List;

/**
 * Resource Query Condition
 *
 * @author monarchCheng
 * @create 2017-11-09 19:54
 **/
public class ResourceQueryCondition2 {

    private String keyword;

    private String title;

    private Date start;

    private Date end;

    private String catalogId;

    private List<String> catalogIds;

    private List<String> departmentIds;

    private List<String> keywordIds;

    private List<String> resourceType;

    private String regionCode;

    private Integer wkid;

    private String fwlx;

    private String dataResource;

    private Date date;

    private String permission;

    private String ndStr;

    public String getPublisher() {
        return publisher;
    }

    public ResourceQueryCondition2 setPublisher(String publisher) {
        this.publisher = publisher;
        return this;
    }

    private String publisher;

    public String getKeyword() {
        return keyword;
    }

    public ResourceQueryCondition2 setKeyword(String keyword) {
        this.keyword = keyword;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public ResourceQueryCondition2 setTitle(String title) {
        this.title = title;
        return this;
    }

    public Date getStart() {
        return start;
    }

    public ResourceQueryCondition2 setStart(Date start) {
        this.start = start;
        return this;
    }

    public Date getEnd() {
        return end;
    }

    public ResourceQueryCondition2 setEnd(Date end) {
        this.end = end;
        return this;
    }


    public String getCatalogId() {
        return catalogId;
    }

    public ResourceQueryCondition2 setCatalogId(String catalogId) {
        this.catalogId = catalogId;
        return this;
    }

    public List<String> getResourceType() {
        return resourceType;
    }

    public ResourceQueryCondition2 setResourceType(List<String> resourceType) {
        this.resourceType = resourceType;
        return this;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public ResourceQueryCondition2 setRegionCode(String regionCode) {
        this.regionCode = regionCode;
        return this;
    }

    public List<String> getCatalogIds() {
        return catalogIds;
    }

    public ResourceQueryCondition2 setCatalogIds(List<String> catalogIds) {
        this.catalogIds = catalogIds;
        return this;
    }

    public Integer getWkid() {
        return wkid;
    }

    public ResourceQueryCondition2 setWkid(Integer wkid) {
        this.wkid = wkid;
        return this;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public List<String> getDepartmentIds() {
        return departmentIds;
    }

    public ResourceQueryCondition2 setDepartmentIds(List<String> departmentIds) {
        this.departmentIds = departmentIds;
        return this;
    }

    public String getDataResource() {
        return dataResource;
    }

    public ResourceQueryCondition2 setDataResource(String dataResource) {
        this.dataResource = dataResource;
        return this;

    }

    public Date getDate() {
        return date;
    }

    public ResourceQueryCondition2 setDate(Date date) {
        this.date = date;
        return this;
    }

    public String getPermission() {
        return permission;
    }

    public ResourceQueryCondition2 setPermission(String permission) {
        this.permission = permission;
        return this;
    }

    public List<String> getKeywordIds() {
        return keywordIds;
    }

    public ResourceQueryCondition2 setKeywordIds(List<String> keywordIds) {
        this.keywordIds = keywordIds;
        return this;
    }

    public String getNdStr() {
        return ndStr;
    }

    public ResourceQueryCondition2 setNdStr(String ndStr) {
        this.ndStr = ndStr;
        return this;
    }


}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/dto/resource/ResourceQueryCondition2.java <==
package cn.gtmap.gtc.resource.domain.resource.dto.resource;

import java.util.Date;
import java.util.List;

/**
 * Resource Query Condition
 *
 * @author monarchCheng
 * @create 2017-11-09 19:54
 **/
public class ResourceQueryCondition2 {

    private String keyword;

    private String title;

    private Date start;

    private Date end;

    private String catalogId;

    private List<String> catalogIds;

    private List<String> departmentIds;

    private List<String> keywordIds;

    private List<String> resourceType;

    private List<String> resourceTypeIds;

    private String regionCode;

    private Integer wkid;

    private String fwlx;

    private String dataResource;

    private Date date;

    private String permission;

    private String ndStr;

    public String getPublisher() {
        return publisher;
    }

    public ResourceQueryCondition2 setPublisher(String publisher) {
        this.publisher = publisher;
        return this;
    }

    private String publisher;

    public String getKeyword() {
        return keyword;
    }

    public ResourceQueryCondition2 setKeyword(String keyword) {
        this.keyword = keyword;
        return this;
    }

    public String getTitle() {
        return title;
    }

    public ResourceQueryCondition2 setTitle(String title) {
        this.title = title;
        return this;
    }

    public Date getStart() {
        return start;
    }

    public ResourceQueryCondition2 setStart(Date start) {
        this.start = start;
        return this;
    }

    public Date getEnd() {
        return end;
    }

    public ResourceQueryCondition2 setEnd(Date end) {
        this.end = end;
        return this;
    }


    public String getCatalogId() {
        return catalogId;
    }

    public ResourceQueryCondition2 setCatalogId(String catalogId) {
        this.catalogId = catalogId;
        return this;
    }

    public List<String> getResourceType() {
        return resourceType;
    }

    public ResourceQueryCondition2 setResourceType(List<String> resourceType) {
        this.resourceType = resourceType;
        return this;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public ResourceQueryCondition2 setRegionCode(String regionCode) {
        this.regionCode = regionCode;
        return this;
    }

    public List<String> getCatalogIds() {
        return catalogIds;
    }

    public ResourceQueryCondition2 setCatalogIds(List<String> catalogIds) {
        this.catalogIds = catalogIds;
        return this;
    }

    public Integer getWkid() {
        return wkid;
    }

    public ResourceQueryCondition2 setWkid(Integer wkid) {
        this.wkid = wkid;
        return this;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public List<String> getDepartmentIds() {
        return departmentIds;
    }

    public ResourceQueryCondition2 setDepartmentIds(List<String> departmentIds) {
        this.departmentIds = departmentIds;
        return this;
    }

    public String getDataResource() {
        return dataResource;
    }

    public ResourceQueryCondition2 setDataResource(String dataResource) {
        this.dataResource = dataResource;
        return this;

    }

    public Date getDate() {
        return date;
    }

    public ResourceQueryCondition2 setDate(Date date) {
        this.date = date;
        return this;
    }

    public String getPermission() {
        return permission;
    }

    public ResourceQueryCondition2 setPermission(String permission) {
        this.permission = permission;
        return this;
    }

    public List<String> getKeywordIds() {
        return keywordIds;
    }

    public ResourceQueryCondition2 setKeywordIds(List<String> keywordIds) {
        this.keywordIds = keywordIds;
        return this;
    }

    public String getNdStr() {
        return ndStr;
    }

    public ResourceQueryCondition2 setNdStr(String ndStr) {
        this.ndStr = ndStr;
        return this;
    }

    public List<String> getResourceTypeIds() {
        return resourceTypeIds;
    }

    public ResourceQueryCondition2 setResourceTypeIds(List<String> resourceTypeIds) {
        this.resourceTypeIds = resourceTypeIds;
        return this;
    }
}
